==> funasr_python-0.1.0.tar.gz: funasr_python-0.1.0/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [Unreleased]

### Added
- Initial FunASR Python Client implementation
- WebSocket-based real-time speech recognition
- Asynchronous and synchronous client APIs
- Configuration management with dotenv support
- Audio processing and streaming capabilities
- Comprehensive error handling
- Connection pooling and management
- Callback system for real-time results
- Unit and integration tests
- Command-line interface
- Multiple audio format support
- Configurable presets for different use cases

### Changed
- N/A

### Deprecated
- N/A

### Removed
- N/A

### Fixed
- N/A

### Security
- N/A

==> funasr_python-0.1.4.tar.gz: funasr_python-0.1.4/CHANGELOG.md <==
# Changelog

All notable changes to this project will be documented in this file.

The format is based on [Keep a Changelog](https://keepachangelog.com/en/1.0.0/),
and this project adheres to [Semantic Versioning](https://semver.org/spec/v2.0.0.html).

## [0.1.3] - 2025-10-29

### Changes
- feat: update ConnectionManager configuration and version to 0.1.2

## [0.1.1] - 2025-10-28

### Changes
- docs: add recognize_stream examples and Two-Pass best practices guide
- Fix integration tests by converting mocked tests to real service integration

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [0.1.0] - 2025-09-26

### Changes
- feat: adapt release script for FunASR Python client and fix dependencies
- Refactor unit tests for FunASR client and configuration management
- feat: change package name from funasr-client to funasr-python
- docs: enhance README with real-time recognition guide and best practices
- Refactor code structure for improved readability and maintainability
- add README

## [Unreleased]

### Added
- Initial FunASR Python Client implementation
- WebSocket-based real-time speech recognition
- Asynchronous and synchronous client APIs
- Configuration management with dotenv support
- Audio processing and streaming capabilities
- Comprehensive error handling
- Connection pooling and management
- Callback system for real-time results
- Unit and integration tests
- Command-line interface
- Multiple audio format support
- Configurable presets for different use cases

### Changed
- N/A

### Deprecated
- N/A

### Removed
- N/A

### Fixed
- N/A

### Security
- N/A
